==> flutter_currency_picker-1.1.5.tar.gz: lib/gen_l10n/app_localization_fr.dart <==
import 'app_localization.dart';

/// The translations for French (`fr`).
class AppLocalizationsFr extends AppLocalizations {
  AppLocalizationsFr([String locale = 'fr']) : super(locale);

  @override
  String get currencyUSD => 'Dollar américain';

  @override
  String get currencyEUR => 'Euro';

  @override
  String get currencyJPY => 'Yen japonais';

  @override
  String get currencyGBP => 'Livre sterling';

  @override
  String get currencyAUD => 'Dollar australien';

  @override
  String get currencyCAD => 'Dollar canadien';

  @override
  String get currencyCHF => 'Franc suisse';

  @override
  String get currencyCNY => 'Chine Yuan Renminbi';

  @override
  String get currencyHKD => 'Dollar de Hong Kong';

  @override
  String get currencyNZD => 'Dollar néo-zélandais';

  @override
  String get currencySEK => 'Couronne suédoise';

  @override
  String get currencyKRW => 'Corée du Sud a gagné';

  @override
  String get currencySGD => 'Dollar de Singapour';

  @override
  String get currencyNOK => 'Couronne norvégienne';

  @override
  String get currencyMXN => 'Peso mexicain';

  @override
  String get currencyINR => 'Roupie indienne';

  @override
  String get currencyRUB => 'Rouble russe';

  @override
  String get currencyZAR => 'Rand d\'Afrique du Sud';

  @override
  String get currencyTRY => 'Lire turque';

  @override
  String get currencyBRL => 'Réal brésilien';

  @override
  String get currencyTWD => 'Nouveau dollar de Taïwan';

  @override
  String get currencyDKK => 'Couronne danoise';

  @override
  String get currencyPLN => 'Pologne Zloty';

  @override
  String get currencyTHB => 'Thaïlande Baht';

  @override
  String get currencyIDR => 'Rupiah indonésienne';

  @override
  String get currencyHUF => 'Forint hongrois';

  @override
  String get currencyCZK => 'Couronne tchèque';

  @override
  String get currencyILS => 'Shekel israélien';

  @override
  String get currencyCLP => 'Peso chilien';

  @override
  String get currencyPHP => 'Peso philippin';

  @override
  String get currencyAED => 'Dirham émirati';

  @override
  String get currencyCOP => 'Peso colombien';

  @override
  String get currencySAR => 'Rial d\'Arabie Saoudite';

  @override
  String get currencyMYR => 'Malaisie Ringgit';

  @override
  String get currencyRON => 'Leu roumain';

  @override
  String get currencyAFN => 'Afghanistan afghan';

  @override
  String get currencyALL => 'Lek albanais';

  @override
  String get currencyDZD => 'Dinar algérien';

  @override
  String get currencyARS => 'Peso argentin';

  @override
  String get currencyAMD => 'Dram arménien';

  @override
  String get currencyAZN => 'Manat azerbaïdjanais';

  @override
  String get currencyBHD => 'Dinar bahreïnien';

  @override
  String get currencyBDT => 'Taka bangladais';

  @override
  String get currencyBBD => 'Dollar de la Barbade';

  @override
  String get currencyBYN => 'Rouble biélorusse';

  @override
  String get currencyBZD => 'Dollar bélizien';

  @override
  String get currencyBMD => 'Dollar des Bermudes';

  @override
  String get currencyBTN => 'Ngultrum bhoutanais';

  @override
  String get currencyBOB => 'Bolivie Bolíviano';

  @override
  String get currencyBAM => 'Mark convertible de Bosnie-Herzégovine';

  @override
  String get currencyBWP => 'Pula du Botswana';

  @override
  String get currencyBND => 'Dollar du Brunéi Darussalam';

  @override
  String get currencyBGN => 'Lev bulgare';

  @override
  String get currencyBIF => 'Franc burundais';

  @override
  String get currencyKHR => 'Riel cambodgien';

  @override
  String get currencyKYD => 'Dollar des îles Caïmans';

  @override
  String get currencyXAF => 'Franc CFA d\'Afrique centrale';

  @override
  String get currencyXOF => 'Franc CFA UEMOA';

  @override
  String get currencyCDF => 'Franc congolais';

  @override
  String get currencyCRC => 'Costa Rica Colon';

  @override
  String get currencyDOP => 'Peso de la République Dominicaine';

  @override
  String get currencyEGP => 'Livre égyptienne';

  @override
  String get currencyETB => 'Birr éthiopien';

  @override
  String get currencyGMD => 'Dalasi gambien';

  @override
  String get currencyGEL => 'Lari géorgien';

  @override
  String get currencyGHS => 'Ghana Cedi';

  @override
  String get currencyGTQ => 'Quetzal guatémaltèque';

  @override
  String get currencyGYD => 'Dollar guyanien';

  @override
  String get currencyHTG => 'Gourde haïtienne';

  @override
  String get currencyISK => 'Couronne islandaise';

  @override
  String get currencyJMD => 'Dollar jamaïcain';

  @override
  String get currencyJOD => 'Dinar jordanien';

  @override
  String get currencyKZT => 'Tenge du Kazakhstan';

  @override
  String get currencyKES => 'Shilling kenyan';

  @override
  String get currencyKWD => 'Dinar koweïtien';

  @override
  String get currencyKGS => 'som kirghize';

  @override
  String get currencyLAK => 'Kip du Laos';

  @override
  String get currencyLRD => 'Dollar du Libéria';

  @override
  String get currencyMKD => 'Macédoine Denar';

  @override
  String get currencyMWK => 'Kwacha malawien';

  @override
  String get currencyMUR => 'Roupie mauricienne';

  @override
  String get currencyMDL => 'Leu moldave';

  @override
  String get currencyMNT => 'Mongolie Tughrik';

  @override
  String get currencyMAD => 'Dirham marocain';

  @override
  String get currencyMZN => 'Metical du Mozambique';

  @override
  String get currencyMMK => 'Myanmar Kyat';

  @override
  String get currencyNAD => 'Dollar namibien';

  @override
  String get currencyNPR => 'Roupie du Népal';

  @override
  String get currencyNIO => 'Nicaragua Cordoue';

  @override
  String get currencyNGN => 'Naira du Nigéria';

  @override
  String get currencyOMR => 'Rial d\'Oman';

  @override
  String get currencyPKR => 'Roupie pakistanaise';

  @override
  String get currencyPGK => 'Kina de Papouasie-Nouvelle-Guinée';

  @override
  String get currencyPYG => 'Guarani du Paraguay';

  @override
  String get currencyPEN => 'Pérou Sol';

  @override
  String get currencyQAR => 'Rial du Qatar';

  @override
  String get currencyRWF => 'Franc rwandais';

  @override
  String get currencyRSD => 'Dinar serbe';

  @override
  String get currencySCR => 'Roupie seychelloise';

  @override
  String get currencySOS => 'Shilling de Somalie';

  @override
  String get currencyLKR => 'Roupie de Sri Lanka';

  @override
  String get currencySRD => 'Dollar du Suriname';

  @override
  String get currencySYP => 'Lire syrienne';

  @override
  String get currencyTZS => 'Shilling tanzanien';

  @override
  String get currencyTTD => 'Dollar de Trinité-et-Tobago';

  @override
  String get currencyTND => 'Dinar tunisien';

  @override
  String get currencyUGX => 'Shilling ougandais';

  @override
  String get currencyUAH => 'Hryvnia ukrainienne';

  @override
  String get currencyUYU => 'Peso uruguayen';

  @override
  String get currencyVEF => 'Venezuela Bolívar';

  @override
  String get currencyVND => 'Viet Nam Dong';

  @override
  String get currencyYER => 'Rial du Yémen';

  @override
  String get currencyZMW => 'kwacha zambien';
}

==> flutter_currency_picker-1.3.4.tar.gz: lib/gen_l10n/app_localization_fr.dart <==
import 'app_localization.dart';

/// The translations for French (`fr`).
class AppLocalizationsFr extends AppLocalizations {
  AppLocalizationsFr([String locale = 'fr']) : super(locale);

  @override
  String get currencyUSD => 'Dollar américain';

  @override
  String get currencyEUR => 'Euro';

  @override
  String get currencyJPY => 'Yen japonais';

  @override
  String get currencyGBP => 'Livre sterling';

  @override
  String get currencyAUD => 'Dollar australien';

  @override
  String get currencyCAD => 'Dollar canadien';

  @override
  String get currencyCHF => 'Franc suisse';

  @override
  String get currencyCNY => 'Chine Yuan Renminbi';

  @override
  String get currencyHKD => 'Dollar de Hong Kong';

  @override
  String get currencyNZD => 'Dollar néo-zélandais';

  @override
  String get currencySEK => 'Couronne suédoise';

  @override
  String get currencyKRW => 'Corée du Sud a gagné';

  @override
  String get currencySGD => 'Dollar de Singapour';

  @override
  String get currencyNOK => 'Couronne norvégienne';

  @override
  String get currencyMXN => 'Peso mexicain';

  @override
  String get currencyINR => 'Roupie indienne';

  @override
  String get currencyRUB => 'Rouble russe';

  @override
  String get currencyZAR => 'Rand d\'Afrique du Sud';

  @override
  String get currencyTRY => 'Lire turque';

  @override
  String get currencyBRL => 'Réal brésilien';

  @override
  String get currencyTWD => 'Nouveau dollar de Taïwan';

  @override
  String get currencyDKK => 'Couronne danoise';

  @override
  String get currencyPLN => 'Pologne Zloty';

  @override
  String get currencyTHB => 'Thaïlande Baht';

  @override
  String get currencyIDR => 'Rupiah indonésienne';

  @override
  String get currencyHUF => 'Forint hongrois';

  @override
  String get currencyCZK => 'Couronne tchèque';

  @override
  String get currencyILS => 'Shekel israélien';

  @override
  String get currencyCLP => 'Peso chilien';

  @override
  String get currencyPHP => 'Peso philippin';

  @override
  String get currencyAED => 'Dirham émirati';

  @override
  String get currencyCOP => 'Peso colombien';

  @override
  String get currencySAR => 'Rial d\'Arabie Saoudite';

  @override
  String get currencyMYR => 'Malaisie Ringgit';

  @override
  String get currencyRON => 'Leu roumain';

  @override
  String get currencyAFN => 'Afghanistan afghan';

  @override
  String get currencyALL => 'Lek albanais';

  @override
  String get currencyDZD => 'Dinar algérien';

  @override
  String get currencyARS => 'Peso argentin';

  @override
  String get currencyAMD => 'Dram arménien';

  @override
  String get currencyAZN => 'Manat azerbaïdjanais';

  @override
  String get currencyBHD => 'Dinar bahreïnien';

  @override
  String get currencyBDT => 'Taka bangladais';

  @override
  String get currencyBBD => 'Dollar de la Barbade';

  @override
  String get currencyBYN => 'Rouble biélorusse';

  @override
  String get currencyBZD => 'Dollar bélizien';

  @override
  String get currencyBMD => 'Dollar des Bermudes';

  @override
  String get currencyBTN => 'Ngultrum bhoutanais';

  @override
  String get currencyBOB => 'Bolivie Bolíviano';

  @override
  String get currencyBAM => 'Mark convertible de Bosnie-Herzégovine';

  @override
  String get currencyBWP => 'Pula du Botswana';

  @override
  String get currencyBND => 'Dollar du Brunéi Darussalam';

  @override
  String get currencyBGN => 'Lev bulgare';

  @override
  String get currencyBIF => 'Franc burundais';

  @override
  String get currencyKHR => 'Riel cambodgien';

  @override
  String get currencyKYD => 'Dollar des îles Caïmans';

  @override
  String get currencyXAF => 'Franc CFA d\'Afrique centrale';

  @override
  String get currencyXOF => 'Franc CFA UEMOA';

  @override
  String get currencyCDF => 'Franc congolais';

  @override
  String get currencyCRC => 'Costa Rica Colon';

  @override
  String get currencyDOP => 'Peso de la République Dominicaine';

  @override
  String get currencyEGP => 'Livre égyptienne';

  @override
  String get currencyETB => 'Birr éthiopien';

  @override
  String get currencyGMD => 'Dalasi gambien';

  @override
  String get currencyGEL => 'Lari géorgien';

  @override
  String get currencyGHS => 'Ghana Cedi';

  @override
  String get currencyGTQ => 'Quetzal guatémaltèque';

  @override
  String get currencyGYD => 'Dollar guyanien';

  @override
  String get currencyHTG => 'Gourde haïtienne';

  @override
  String get currencyISK => 'Couronne islandaise';

  @override
  String get currencyJMD => 'Dollar jamaïcain';

  @override
  String get currencyJOD => 'Dinar jordanien';

  @override
  String get currencyKZT => 'Tenge du Kazakhstan';

  @override
  String get currencyKES => 'Shilling kenyan';

  @override
  String get currencyKWD => 'Dinar koweïtien';

  @override
  String get currencyKGS => 'Som Kirghize';

  @override
  String get currencyUZS => 'Somme Ouzbèke';

  @override
  String get currencyLAK => 'Kip du Laos';

  @override
  String get currencyLRD => 'Dollar du Libéria';

  @override
  String get currencyMKD => 'Macédoine Denar';

  @override
  String get currencyMWK => 'Kwacha malawien';

  @override
  String get currencyMUR => 'Roupie mauricienne';

  @override
  String get currencyMDL => 'Leu moldave';

  @override
  String get currencyMNT => 'Mongolie Tughrik';

  @override
  String get currencyMAD => 'Dirham marocain';

  @override
  String get currencyMZN => 'Metical du Mozambique';

  @override
  String get currencyMMK => 'Myanmar Kyat';

  @override
  String get currencyNAD => 'Dollar namibien';

  @override
  String get currencyNPR => 'Roupie du Népal';

  @override
  String get currencyNIO => 'Nicaragua Cordoue';

  @override
  String get currencyNGN => 'Naira du Nigéria';

  @override
  String get currencyOMR => 'Rial d\'Oman';

  @override
  String get currencyPKR => 'Roupie pakistanaise';

  @override
  String get currencyPGK => 'Kina de Papouasie-Nouvelle-Guinée';

  @override
  String get currencyPYG => 'Guarani du Paraguay';

  @override
  String get currencyPEN => 'Pérou Sol';

  @override
  String get currencyQAR => 'Rial du Qatar';

  @override
  String get currencyRWF => 'Franc rwandais';

  @override
  String get currencyRSD => 'Dinar serbe';

  @override
  String get currencySCR => 'Roupie seychelloise';

  @override
  String get currencySOS => 'Shilling de Somalie';

  @override
  String get currencyLKR => 'Roupie de Sri Lanka';

  @override
  String get currencySRD => 'Dollar du Suriname';

  @override
  String get currencySYP => 'Lire syrienne';

  @override
  String get currencyTZS => 'Shilling tanzanien';

  @override
  String get currencyTTD => 'Dollar de Trinité-et-Tobago';

  @override
  String get currencyTND => 'Dinar tunisien';

  @override
  String get currencyUGX => 'Shilling ougandais';

  @override
  String get currencyUAH => 'Hryvnia ukrainienne';

  @override
  String get currencyUYU => 'Peso uruguayen';

  @override
  String get currencyVEF => 'Venezuela Bolívar';

  @override
  String get currencyVND => 'Viet Nam Dong';

  @override
  String get currencyYER => 'Rial du Yémen';

  @override
  String get currencyZMW => 'kwacha zambien';
}
